
[![](https://codecov.io/gh/nickderobertis/project-report/branch/master/graph/badge.svg)](https://codecov.io/gh/nickderobertis/project-report)

# project-report

## Overview

Find software projects, analyze them, and output a report.

## Getting Started

Install `project-report`:

```
pip install project-report
```

A simple example:

```python
import projectreport

# Do something with projectreport
```

## Links

See the
[documentation here.](
https://nickderobertis.github.io/project-report/
)

## Author

Created by Nick DeRobertis. MIT License.
